<?php

include_once 'util.php';

/**
 * Mantis Projects
 * 
 * @param Bugzilla products record $src
 */
function project($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_project_table SET ";
    
    $fields = array(
        'id'                => $src['id'],
        'name'               => $src['name'],
        'status'             => 10,
        'enabled'           => $src['isactive'],
        'view_state'        => 10,
        'access_min'        => 10,
        'description'        => $src['description'],
        'category_id'       => $src['classification_id'],
        'inherit_global'    => 1
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    return $msql;
}

/**
 * Mantis SubProject and project hierarchy
 * 
 * @param Bugzilla components record $src
 */
function component2Project($src) {
    global $DB;
    $msql = array();
    $sql  = "INSERT INTO mantis_project_table SET ";
    
    $computedId = $src['id'] + $DB->getMax("products", "id");
    
    $fields = array(
        'id'                => $computedId,
        'name'              => $src['name'],
        'status'               => 10,
        'enabled'            => 1,
        'view_state'        => 10,
        'access_min'        => 10,
        'description'       => $src['description'],
        'inherit_global'    => 1
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    
    $sql  = "INSERT INTO mantis_project_hierarchy_table SET ";
    $fields = array(
        'child_id'          => $computedId,
        'parent_id'         => $src['product_id'],
        'inherit_parent'    => 1
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;

    return $msql;
}

/**
 * Mantis User table
 * 
 * @param Bugzilla profiles record $src
 */
function user($src) {
    $msql = array();
    // Never overwrite administrator user
    if ($src['userid'] != 1) {
        $sql  = "INSERT INTO mantis_user_table SET ";
        
        $fields = array(
            'id'               => $src['userid'],
            'username'         => $src['login_name'],
            'realname'         => $src['realname'],
            'password'         => $src['cryptpassword'],
            'enabled'          => ( $src['disabledtext'] == "") ? 1 : 0,
            'cookie_string'    => randomToken()
        );
        $sql = $sql.buildColumnSet($fields);
        $msql[] = $sql;
    }
  
    return $msql;  
}

/**
 * Mantis Project Versions
 * 
 * @param Bugzilla versions record $src
 */
function version($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_project_version_table SET ";
    
    $fields = array(
        'id'            => $src['id'],
        'project_id'    => $src['product_id'],
        'version'       => $src['value']
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
  
    return $msql;     
}

/**
 * Mantis Bug Monitor Table
 * 
 * @param Bugzilla cc record $src
 */
function ccMonitorBug($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_monitor_table SET ";
    
    $fields = array(
        'user_id'    => $src['who'],
        'bug_id'     => $src['bug_id']
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
  
    return $msql; 
}


/**
 * Mantis Bug Table
 * 
 * @param Bugzilla bugs record $src
 */
function bug($src) {
    global $DB;
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_table SET ";

    $computedId = $src['component_id'] + $DB->getMax("products", "id");

    $fields = array(
        'id'             => $src['bug_id'],
        'project_id'     => $computedId,
        'reporter_id'    => $src['reporter'],
        'handler_id'     => $src['assigned_to'],
        'priority'       => $DB->getMapping("priority",$src['priority']),
        'severity'       => $DB->getMapping("severity",$src['bug_severity']),
        'status'         => $DB->getMapping("status",$src['bug_status']),
        'resolution'     => $DB->getMapping("resolution",($src['resolution'] != "" ? $src['resolution'] : "OPEN" )),
        'bug_text_id'    => $src['bug_id'],
        'os'             => $src['op_sys'],
        'platform'       => $src['rep_platform'],
        'version'        => $src['version'],
        'summary'        => $src['short_desc'],
        'sponsorship_total' => $src['votes'],
        'target_version' => $src['target_milestone'],
        'date_submitted' => unixTime($src['creation_ts']),
        'due_date'       => 1,
        'last_updated'   => unixTime($src['delta_ts'])
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    
    // UPDATE bug history
    $sql  = "INSERT INTO mantis_bug_history_table SET ";
    $fields = array(
        'user_id'       => $src['reporter'],
        'bug_id'        => $src['bug_id'],
        'field_name'    => "",
        'old_value'     => "",
        'new_value'     => "",
        'type'          => NEW_BUG,
        'date_modified' => unixTime($src['creation_ts']),
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
     
    return $msql;
}

/**
 * Updates duplicate_id, and relationships
 * 
 * @param Bugzilla duplicates record $src
 */
function duplicates($src) {
    $msql = array();
    $sql  = "UPDATE mantis_bug_table SET ";
    $sql  .= "duplicate_id=".$src['dupe_of'];
    $sql  .= " WHERE id=".$src['dupe'];
    $msql[] = $sql;
    
    // Mark relationship too
    $sql  = "INSERT INTO mantis_bug_relationship_table SET ";
    $fields = array(
        'source_bug_id'      => $src['dupe'],
        'destination_bug_id' => $src['dupe_of'],
        'relationship_type'  => 0
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    return $msql;
}

/**
 * Mantis Bug Text table
 *
 * @param Bugzilla bugs_fulltext record $src
 */
function bugText($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_text_table SET ";
    
    $fields = array(
        'id'                        => $src['bug_id'],
        'description'               => $src['short_desc'],
        'steps_to_reproduce'        => "",
        'additional_information'    => "" 
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
  
    return $msql;
}

/**
 * Mantis Bug History Table
 * 
 * @param Bugzilla bugs_activity record $src
 */
function bugActivity($src) {
    global $DB;
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_history_table SET ";
    
    $name = $DB->getMapping("field",$src['fieldid']);
    $type = $DB->getMapping('type', $src['fieldid']);
    
    // If we can't get a name or type for the change, skip it
    if ($type != "" || $name != "") {
        if (preg_match_all("/_ts/", $name)) {
            // Is a timestamp, correct values
            $src['removed']  = unixTime($src['removed']);
            $src['added']    = unixTime($src['added']);
        }
        if ($name == "component") {
            // Remap to new project id
            $src['removed']  += $DB->getMax("products", "id");
            $src['added']    += $DB->getMax("products", "id");
        }
        
        $fields = array(
            'user_id'       => $src['who'],
            'bug_id'        => $src['bug_id'],
            'field_name'    => $name,
            'old_value'     => $src['removed'],
            'new_value'     => $src['added'],
            'type'          => $type,
            'date_modified' => $src['bug_when']
        );
        $sql = $sql.buildColumnSet($fields);
        
    } else {
        $sql = "/* Unknown mapping from ".$src['fieldid']." to (".$name.",".$type.")*/";
        
    }
    $msql[] = $sql;
    
    return $msql;   
}

/**
 * Mantis Bug File table
 *
 * @param Bugzilla attachments record $src
 */
function files($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_file_table SET ";
    
    $fields = array(
        'id'            => $src['attach_id'],
        'bug_id'        => $src['bug_id'],
        'title'         => $src['filename'], 
        'description'   => $src['description'],
        'filename'      => $src['filename'],
        'file_type'     => $src['mimetype'], 
        'date_added'    => unixTime($src['creation_ts']),
        'user_id'       => $src['submitter_id']
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    
    // UPDATE bug history
    $sql  = "INSERT INTO mantis_bug_history_table SET ";
    $fields = array(
        'user_id'       => $src['submitter_id'],
        'bug_id'        => $src['bug_id'],
        'field_name'    => "",
        'old_value'     => "",
        'new_value'     => $src['filename'],
        'type'          => FILE_ADDED,
        'date_modified' => unixTime($src['creation_ts']),
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;  
    return $msql; 
}

/**
 * Update Mantis Bug File table with file contents
 *
 * @param Bugzilla attach_data record $src
 */
function fileData($src) {
    $msql = array();
    $sql  = "UPDATE mantis_bug_file_table SET ";
    
    // FIX: Attachment data isn't correct (bad escaping?)
    $fields = array(
        'content'    => $src['thedata'],
        'filesize'   => strlen($src['thedata'])
    );
    $sql = $sql.buildColumnSet($fields);
    $sql = $sql." WHERE id=".$src['id'];
    $msql[] = $sql;
  
    return $msql;  
}

/**
 * Mantis relationship
 *
 * @param Bugzilla dependencies record $src
 */
function relationship($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_relationship_table SET ";
    
    $fields = array(
        'source_bug_id'      => $src['dependson'],  // fill
        'destination_bug_id' => $src['blocked'],    // Pare
        'relationship_type'  => 2
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
  
    return $msql;  
}

/**
 * Mantis Tag
 * 
 * @param Bugzilla flagtypes record $src
 */
function tag($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_tag_table SET ";
    
    $fields = array(
        'id'            => $src['id'],
        'name'          => $src['name'],
        'description'   => $src['description']
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
  
    return $msql;
}

/**
 * Mantis bug tag
 *
 * @param Bugzilla flags record $src
 */
function bugtag($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_bug_tag_table SET ";
    
    $fields = array(
        'bug_id'        => $src['bug_id'],
        'tag_id'        => $src['type_id'],
        'user_id'       => $src['setter_id'],
        'date_attached' => unixTime($src['creation_date'])
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    
    // UPDATE bug history
    $sql  = "INSERT INTO mantis_bug_history_table SET ";
    $fields = array(
        'user_id'       => $src['setter_id'],
        'bug_id'        => $src['bug_id'],
        'field_name'    => "",
        'old_value'     => "",
        'new_value'     => $src['tag_id'],
        'type'          => TAG_ATTACHED,
        'date_modified' => unixTime($src['creation_date']),
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;   
  
    return $msql;
}

/**
 * Mantis bugnote and bugnote_text
 * 
 * @param Bugzilla longdescs record $src
 */
function note($src) {
    $msql = array();
    $sql  = "INSERT INTO mantis_bugnote_table SET ";
    $fields = array(
        'id'                => $src['comment_id'],
        'bug_id'            => $src['bug_id'],
        'reporter_id'       => $src['who'],
        'bugnote_text_id'   => $src['comment_id'],
        'view_state'        => ($src['isprivate'] != 0) ? 50 : 10,
        'time_tracking'     => $src['work_time'],
        'last_modified'     => unixTime($src['bug_when']),
        'date_submitted'    => unixTime($src['bug_when'])
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    
    $sql  = "INSERT INTO mantis_bugnote_text_table SET ";
    $fields = array(
        'id'    => $src['comment_id'],
        'note'  => $src['thetext']
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    
    // UPDATE bug history
    $sql  = "INSERT INTO mantis_bug_history_table SET ";
    $fields = array(
        'user_id'       => $src['who'],
        'bug_id'        => $src['bug_id'],
        'field_name'    => "",
        'old_value'     => "",
        'new_value'     => "",
        'type'          => BUGNOTE_ADDED,
        'date_modified' => unixTime($src['bug_when'])
    );
    $sql = $sql.buildColumnSet($fields);
    $msql[] = $sql;
    return $msql;
}



?>

